# Schemarin

Schemarin is a color scheme manager for [iTerm2](https://iterm2.com) that should really be installed with 
[Homebrew](https://brew.sh) rather than pip.

```bash
brew tap celsiusnarhwal/htt
brew install schemarin
```

Schemarin is published on PyPI **for technical reasons only** and is not intended to be installed with pip or other
Python package managers.

For more information, [check out Schemarin's GitHub repository](https://schemarin.celsiusnarhwal.dev).